==> Omni-0.9.1.tar.gz: Omni/XMLDevice/XMLDevicePrintMode.hpp <==
/*
 *   IBM Omni driver
 *   Copyright (c) International Business Machines Corp., 2000
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Lesser General Public License as published
 *   by the Free Software Foundation; either version 2.1 of the License, or
 *   (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public License
 *   along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef _XMLDevicePrintMode
#define _XMLDevicePrintMode

#include <DevicePrintMode.hpp>
#include <XMLDevice.hpp>

class XMLDevicePrintMode : public DevicePrintMode
{
public:
                             XMLDevicePrintMode   (Device                   *pDevice,
                                                   PSZRO                     pszJobProperties,
                                                   int                       iPhysicalCount,
                                                   int                       iLogicalCount,
                                                   int                       iPlanes,
                                                   xmlNodePtr                node);
   virtual                  ~XMLDevicePrintMode   ();

   virtual DevicePrintMode  *create               (Device                   *pDevice,
                                                   PSZRO                     pszJobProperties);
   static DevicePrintMode   *createS              (Device                   *pDevice,
                                                   PSZRO                     pszJobProperties);

   virtual bool              isSupported          (PSZCRO                    pszJobProperties);

   virtual PSZCRO            getDeviceID          ();

   virtual Enumeration      *getEnumeration       (bool                      fInDeviceSpecific);

#ifndef RETAIL
   void                      outputSelf           ();
#endif
   virtual std::string       toString             (std::ostringstream&       oss);
   friend std::ostream&      operator<<           (std::ostream&             os,
                                                   const XMLDevicePrintMode& self);

private:
   static xmlNodePtr         findPrintModes       (XMLDevice                *pXMLDevice);

   xmlNodePtr node_d;
   PSZRO      pszDeviceID_d;
};

#endif

==> Omni-0.9.2.tar.gz: Omni/XMLDevice/XMLDevicePrintMode.hpp <==
/*
 *   IBM Omni driver
 *   Copyright (c) International Business Machines Corp., 2000
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Lesser General Public License as published
 *   by the Free Software Foundation; either version 2.1 of the License, or
 *   (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public License
 *   along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef _XMLDevicePrintMode
#define _XMLDevicePrintMode

#include <DevicePrintMode.hpp>
#include <XMLDevice.hpp>

class XMLDevicePrintMode : public DevicePrintMode
{
public:
                             XMLDevicePrintMode   (Device                   *pDevice,
                                                   PSZRO                     pszJobProperties,
                                                   int                       iPhysicalCount,
                                                   int                       iLogicalCount,
                                                   int                       iPlanes,
                                                   XmlNodePtr                node);
   virtual                  ~XMLDevicePrintMode   ();

   virtual DevicePrintMode  *create               (Device                   *pDevice,
                                                   PSZRO                     pszJobProperties);
   static DevicePrintMode   *createS              (Device                   *pDevice,
                                                   PSZRO                     pszJobProperties);

   virtual bool              isSupported          (PSZCRO                    pszJobProperties);

   virtual PSZCRO            getDeviceID          ();

   virtual Enumeration      *getEnumeration       (bool                      fInDeviceSpecific);

#ifndef RETAIL
   void                      outputSelf           ();
#endif
   virtual std::string       toString             (std::ostringstream&       oss);
   friend std::ostream&      operator<<           (std::ostream&             os,
                                                   const XMLDevicePrintMode& self);

private:
   static XmlNodePtr         findPrintModes       (XMLDevice                *pXMLDevice);

   XmlNodePtr node_d;
   PSZRO      pszDeviceID_d;
};

#endif
